import {
  createContext,
  useContext,
  useState,
  useEffect,
  useCallback,
} from "react";
import {
  supabase,
  signUp as supabaseSignUp,
  signIn as supabaseSignIn,
  signOut as supabaseSignOut,
  getCurrentUser,
  getUserProfile,
} from "../services/supabase";

const AuthContext = createContext();

export function useAuth() {
  const context = useContext(AuthContext);
  if (!context) {
    throw new Error("useAuth must be used within an AuthProvider");
  }
  return context;
}

export function AuthProvider({ children }) {
  const [currentUser, setCurrentUser] = useState(null);
  const [userProfile, setUserProfile] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  const signup = useCallback(async (email, password, username) => {
    try {
      setError(null);
      const result = await supabaseSignUp(email, password, username);
      return result;
    } catch (error) {
      const errorMessage = error.message || "Failed to sign up";
      setError(errorMessage);
      throw error;
    }
  }, []);

  const login = useCallback(async (email, password) => {
    try {
      setError(null);
      const result = await supabaseSignIn(email, password);
      return result;
    } catch (error) {
      const errorMessage = error.message || "Failed to log in";
      setError(errorMessage);
      throw error;
    }
  }, []);

  const logout = useCallback(async () => {
    try {
      setError(null);
      await supabaseSignOut();
      setCurrentUser(null);
      setUserProfile(null);
    } catch (error) {
      const errorMessage = error.message || "Failed to log out";
      setError(errorMessage);
      throw error;
    }
  }, []);

  const fetchUserProfile = useCallback(async (uid) => {
    if (!uid) return null;
    try {
      setError(null);
      return await getUserProfile(uid);
    } catch (error) {
      const errorMessage = error.message || "Failed to fetch user profile";
      setError(errorMessage);
      return null;
    }
  }, []);

  useEffect(() => {
    let authSubscription;

    const initializeAuth = async () => {
      try {
        setError(null);
        const user = await getCurrentUser();
        if (user) {
          setCurrentUser(user);
          const profile = await fetchUserProfile(user.id);
          setUserProfile(profile);
        }

        const {
          data: { subscription },
        } = supabase.auth.onAuthStateChange(async (event, session) => {
          if (session?.user) {
            setCurrentUser(session.user);
            const profile = await fetchUserProfile(session.user.id);
            setUserProfile(profile);
          } else {
            setCurrentUser(null);
            setUserProfile(null);
          }
        });
        authSubscription = subscription;
      } catch (error) {
        const errorMessage = error.message || "Failed to initialize auth";
        setError(errorMessage);
      } finally {
        setLoading(false);
      }
    };

    initializeAuth();

    return () => {
      if (authSubscription) {
        authSubscription.unsubscribe();
      }
    };
  }, [fetchUserProfile]);

  const value = {
    currentUser,
    userProfile,
    signup,
    login,
    logout,
    loading,
    error,
    updateProfile: fetchUserProfile,
  };

  return (
    <AuthContext.Provider value={value}>
      {!loading && children}
    </AuthContext.Provider>
  );
}
