import { useState } from "react";
import { Link, useNavigate } from "react-router-dom";
import { useAuth } from "../contexts/AuthContext";

function LoginPage() {
  const [formData, setFormData] = useState({
    email: "",
    password: "",
  });
  const [error, setError] = useState("");
  const [loading, setLoading] = useState(false);

  const { login } = useAuth();
  const navigate = useNavigate();

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]: value,
    }));
  };

  const handleSubmit = async (e) => {
    e.preventDefault();

    if (!formData.email || !formData.password) {
      setError("Заполните все поля");
      return;
    }

    try {
      setError("");
      setLoading(true);

      const { error } = await login(formData.email, formData.password);

      if (error) throw error;

      navigate("/", { replace: true });
    } catch (err) {
      console.error("Login error:", err);
      setError(
        err.message === "Invalid login credentials"
          ? "Неверный email или пароль"
          : "Ошибка при входе. Попробуйте позже"
      );
    } finally {
      setLoading(false);
    }
  };

  return (
    <div className="pt-20 min-h-screen flex items-center justify-center bg-campfire-dark">
      <div className="container-custom max-w-md py-12">
        <div className="bg-campfire-charcoal rounded-lg shadow-lg p-8 border border-campfire-ash/20">
          <div className="text-center mb-8">
            <h1 className="text-3xl font-bold text-campfire-light mb-2">
              Вход в CampFire
            </h1>
            <p className="text-campfire-ash">
              Войдите, чтобы оценивать и рецензировать контент
            </p>
          </div>

          {error && (
            <div className="bg-status-error/20 text-status-error p-3 rounded-md mb-6 text-sm">
              {error}
            </div>
          )}

          <form onSubmit={handleSubmit} className="space-y-6">
            <div>
              <label
                htmlFor="email"
                className="block text-sm font-medium text-campfire-light mb-1"
              >
                Email
              </label>
              <input
                type="email"
                id="email"
                name="email"
                value={formData.email}
                onChange={handleChange}
                className="input w-full"
                placeholder="your@email.com"
                required
                autoComplete="email"
              />
            </div>

            <div>
              <div className="flex justify-between items-center mb-1">
                <label
                  htmlFor="password"
                  className="block text-sm font-medium text-campfire-light"
                >
                  Пароль
                </label>
                <Link
                  to="/forgot-password"
                  className="text-xs text-campfire-amber hover:text-campfire-ember transition-colors"
                >
                  Забыли пароль?
                </Link>
              </div>
              <input
                type="password"
                id="password"
                name="password"
                value={formData.password}
                onChange={handleChange}
                className="input w-full"
                placeholder="••••••••"
                required
                autoComplete="current-password"
              />
            </div>

            <button
              type="submit"
              disabled={loading}
              className={`btn-primary w-full ${loading ? "opacity-80" : ""}`}
            >
              {loading ? (
                <span className="inline-flex items-center">
                  <svg
                    className="animate-spin -ml-1 mr-2 h-4 w-4 text-white"
                    xmlns="http://www.w3.org/2000/svg"
                    fill="none"
                    viewBox="0 0 24 24"
                  >
                    <circle
                      className="opacity-25"
                      cx="12"
                      cy="12"
                      r="10"
                      stroke="currentColor"
                      strokeWidth="4"
                    ></circle>
                    <path
                      className="opacity-75"
                      fill="currentColor"
                      d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"
                    ></path>
                  </svg>
                  Вход...
                </span>
              ) : (
                "Войти"
              )}
            </button>
          </form>

          <div className="mt-6 text-center text-sm text-campfire-ash">
            Нет аккаунта?{" "}
            <Link
              to="/register"
              className="text-campfire-amber hover:text-campfire-ember font-medium transition-colors"
            >
              Зарегистрироваться
            </Link>
          </div>
        </div>
      </div>
    </div>
  );
}

export default LoginPage;
